@@ -51,14 +51,15 @@ def make_sentences_max_length(sentences, max_len=64, min_len=10):
             new_sentences.append(sub_sentences[0])
             if len(sub_sentences) == 1: continue
 
+            new_sentences[-1] = new_sentences[-1] + '，'
             for sub_s in sub_sentences[1:-1]:
                 if len(new_sentences[-1]) < max_len:
-                    new_sentences[-1] = new_sentences[-1] + '，' + sub_s
+                    new_sentences[-1] = new_sentences[-1] + sub_s + '，'
                 else:
-                    new_sentences.append(sub_s)
+                    new_sentences.append(sub_s + '，')
 
             if len(sub_sentences[-1]) < min_len:
-                new_sentences[-1] = new_sentences[-1] + '，' + sub_sentences[-1]
+                new_sentences[-1] = new_sentences[-1] + sub_sentences[-1]
             else:
                 new_sentences.append(sub_sentences[-1])
 
